==> libgrinvin-invariants-java_1.0.2.orig.tar.gz: grinvin-invariants-1.0.2/org/grinvin/invariants/computers/simple/AverageEccentricity.java <==
/* AverageEccentricity.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.invariants.computers.simple;

import org.grinvin.GraphBundleView;
import org.grinvin.invariants.RealValue;
import org.grinvin.invariants.computers.AbstractInvariantComputer;

/**
 * Computes the average eccentricity of the graph.
 */
public class AverageEccentricity extends AbstractInvariantComputer {
    
    public RealValue compute (GraphBundleView bundle) {
        int[] eccentricityList = bundle.eccentricityList();
        int n = eccentricityList.length;
        if (n <= 1) {
            if (n == 0)
                return RealValue.undefinedValue (this);
            else 
                return new RealValue (0, this);
        }
        if(eccentricityList[1]==Integer.MAX_VALUE)
            return RealValue.positiveInfinity(this);
        double averageEccentricity = 0.0;
        for (int eccentricity : eccentricityList)
            averageEccentricity += (1.0*eccentricity)/n;
        return new RealValue (averageEccentricity, this);
    }
    
    public String getInvariantId () {
        return "org.grinvin.invariants.AverageEccentricity";
    }
}

==> libgrinvin-invariants-java_1.2.orig.tar.gz: grinvin-invariants-1.2/org/grinvin/invariants/computers/simple/AverageEccentricity.java <==
/* AverageEccentricity.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.invariants.computers.simple;

import org.grinvin.graphs.GraphBundleView;
import org.grinvin.invariants.computers.AbstractInvariantComputer;
import org.grinvin.invariants.values.RealValue;

/**
 * Computes the average eccentricity of the graph.
 */
public class AverageEccentricity extends AbstractInvariantComputer {
    
    public RealValue compute (GraphBundleView bundle) {
        int[] eccentricityList = bundle.eccentricityList();

        int n = eccentricityList.length;
        if (n <= 1) {
            if (n == 0)
                return RealValue.undefinedValue (this);
            else 
                return new RealValue (0, this);
        }
        if(eccentricityList[1]==Integer.MAX_VALUE)
            return RealValue.positiveInfinity(this);
        double averageEccentricity = 0.0;
        for (int eccentricity : eccentricityList)
            averageEccentricity += (1.0*eccentricity)/n;
        return new RealValue (averageEccentricity, this);
    }
    
    public String getInvariantId () {
        return "org.grinvin.invariants.AverageEccentricity";
    }
}
